@@ -40,7 +40,7 @@ from pytensor.tensor.variable import TensorConstant
 
 import pymc as pm
 
-from pymc import Deterministic, Potential
+from pymc import Deterministic, Model, Potential
 from pymc.blocking import DictToArrayBijection, RaveledVars
 from pymc.distributions import Normal, transforms
 from pymc.distributions.distribution import PartialObservedRV
@@ -223,6 +223,14 @@ class TestObserved:
         assert x1.type.dtype == X.type.dtype
         assert x2.type.dtype == X.type.dtype
 
+    @pytensor.config.change_flags(compute_test_value="raise")
+    def test_observed_compute_test_value(self):
+        data = np.zeros(100)
+        with pm.Model():
+            obs = pm.Normal("obs", mu=pt.zeros_like(data), sigma=1, observed=data)
+        assert obs.tag.test_value.shape == data.shape
+        assert obs.tag.test_value.dtype == data.dtype
+
 
 def test_duplicate_vars():
     with pytest.raises(ValueError) as err:
@@ -1516,6 +1524,18 @@ class TestImputationMissingData:
             st.norm.logcdf(0) * 10,
         )
 
+    def test_truncated_normal(self):
+        """Test transform of unobserved TruncatedNormal leads to finite logp.
+
+        Regression test for #6999
+        """
+        with Model() as m:
+            mu = pm.TruncatedNormal("mu", mu=1, sigma=2, lower=0)
+            x = pm.TruncatedNormal(
+                "x", mu=mu, sigma=0.5, lower=0, observed=np.array([0.1, 0.2, 0.5, np.nan, np.nan])
+            )
+        m.check_start_vals(m.initial_point())
+
 
 class TestShared:
     def test_deterministic(self):
